@@ -46,10 +46,8 @@ setMethod(
 #'       \item \code{size_edge} relative size of edge width.
 #'       \item \code{node_label} Select which labels to be displayed,
 #'         one of 'category', 'group', 'all' and 'none'.
+#'       \item \code{node_label_size} size of node label, default is 5.
 #'       \item \code{pie} one of 'equal' or 'Count' to set the slice ratio of the pies (for `compareClusterResult` only).
-#'       \item \code{group} logical, if TRUE, group the category.
-#'       \item \code{group_style} style of ellipse, one of "ggforce" an "polygon"
-#'       \item \code{label_group_style} style of group label, one of "shadowtext" and "ggforce".
 #'       \item \code{label_format} a numeric value sets wrap length, alternatively a custom function to format axis labels.
 #'       \item \code{clusterFunction} function of Clustering method, such as stats::kmeans(the default),
 #'         cluster::clara, cluster::fanny or cluster::pam.
@@ -65,7 +63,7 @@ ssplot.enrichResult <- function(
     showCategory = 30,
     drfun = NULL,
     dr.params = list(),
-    group = TRUE,
+    #group = TRUE,
     node_label = "group",
     ...
 ) {
@@ -89,7 +87,7 @@ ssplot.enrichResult <- function(
     p <- emapplot(
         x = x,
         showCategory = showCategory,
-        group = group,
+        #group = group,
         node_label = node_label,
         ...
     )
@@ -117,7 +115,6 @@ ssplot.compareClusterResult <- function(
     drfun = NULL,
     #cex_pie2axis = 0.0125,
     dr.params = list(),
-    group = TRUE,
     node_label = "group",
     ...
 ) {
@@ -149,7 +146,7 @@ ssplot.compareClusterResult <- function(
         pie = pie,
         #with_edge = with_edge,
         #cex_pie2axis = cex_pie2axis,
-        group = group,
+        #group = group,
         node_label = node_label,
         ...
     )
